Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(538)

Unified Diff: chrome/browser/browser_process_impl.h

Issue 7058041: Remove ResourceDispatcherHost dependency on Chrome's LoginHandler and ExternalProtocolHandler. (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: fix deps Created 9 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/browser_process_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/browser_process_impl.h
===================================================================
--- chrome/browser/browser_process_impl.h (revision 87739)
+++ chrome/browser/browser_process_impl.h (working copy)
@@ -28,7 +28,7 @@
#include "ipc/ipc_message.h"
class ChromeNetLog;
-class ChromeResourceDispatcherHostObserver;
+class ChromeResourceDispatcherHostDelegate;
class CommandLine;
class DevToolsHttpProtocolHandler;
class DevToolsProtocolHandler;
@@ -286,12 +286,12 @@
// Lives here so can safely log events on shutdown.
scoped_ptr<ChromeNetLog> net_log_;
// Ordered before resource_dispatcher_host_observer_ due to destruction
// ordering.
scoped_ptr<prerender::PrerenderTracker> prerender_tracker_;
- scoped_ptr<ChromeResourceDispatcherHostObserver>
- resource_dispatcher_host_observer_;
+ scoped_ptr<ChromeResourceDispatcherHostDelegate>
+ resource_dispatcher_host_delegate_;
NotificationRegistrar notification_registrar_;
scoped_refptr<PluginDataRemover> plugin_data_remover_;
« no previous file with comments | « no previous file | chrome/browser/browser_process_impl.cc » ('j') | no next file with comments »
@@ -286,12 +286,12 @@
// Lives here so can safely log events on shutdown.
scoped_ptr<ChromeNetLog> net_log_;
- // Ordered before resource_dispatcher_host_observer_ due to destruction
+ // Ordered before resource_dispatcher_host_delegate_ due to destruction
// ordering.
scoped_ptr<prerender::PrerenderTracker> prerender_tracker_;

Powered by Google App Engine
This is Rietveld 408576698